/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package DAO;

import java.sql.Connection;
import java.sql.DatabaseMetaData;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.List;

/**
 *
 * @author puiss
 */
public class SQLiteManager {
    
    private static final String[] months = {"Janvrier","Fevrier","Mars","Avril","Mai","Juin","Juillet","Aout","Septembre","Octobre","Novembre","Decembre"};
    public SQLiteManager(String name) {
 
        String url = "jdbc:sqlite:C:/sqlite/" + name;
 
        try (Connection conn = DriverManager.getConnection(url)) {
            if (conn != null) {
                DatabaseMetaData meta = conn.getMetaData();
                createNewTable(url);
            }
 
        } catch (SQLException e) {
            e.printStackTrace();
        }
    }
    
    
    /**
     * Create a new table in the test database
     *
     */
    public static void createNewTable(String url) {
        // SQLite connection string
        
        // SQL statement for creating a new table
        String sql = "CREATE TABLE IF NOT EXISTS data (\n"
                + "	id integer PRIMARY KEY AUTOINCREMENT,\n"
                + "     month integer NOT NULL CHECK(month <= 12 and month > 0),\n"
                + "     week integer NOT NULL CHECK (week <= 5 and week > 0),\n"
                + "     day integer NOT NULL CHECK(day <= 31 and day > 0),\n"
                + "     hour integer NOT NULL CHECK(hour <24 and hour >= 0),\n"
                + "     min integer NOT NULL CHECK(min <60 and min >= 0),\n"
                + "	intensity integer,\n"
                + "     temperature integer,\n"
                + "	humidityAir integer,\n"
                + "     humidityPlant integer\n"
                + ");";
        
        try (Connection conn = DriverManager.getConnection(url);
                Statement stmt = conn.createStatement()) {
            // create a new table
            stmt.execute(sql);
        } catch (SQLException e) {
            System.out.println(url + " " + e.getMessage());
            e.printStackTrace();
            
        }
    }
    
     private Connection connect() {
        // SQLite connection string
        String url = "jdbc:sqlite:C:/sqlite/plant.db";
        Connection conn = null;
        try {
            conn = DriverManager.getConnection(url);
        } catch (SQLException e) {
            e.printStackTrace();
        }
        return conn;
    }
     
    public void insert(int month, int week, int day, int hour, int min, int it, int temp, int humiA, int humiT) {
        String sql = "INSERT INTO data(month,week,day,hour,min,intensity,temperature,humidityAir,humidityPlant) VALUES(?,?,?,?,?,?,?,?,?)";
        
        try (Connection conn = this.connect();
                PreparedStatement pstmt = conn.prepareStatement(sql)) {
            pstmt.setInt(1, month);
            pstmt.setInt(2,week);
            pstmt.setInt(3, day);
            pstmt.setInt(4, hour);
            pstmt.setInt(5, min);
            pstmt.setInt(6, it);
            pstmt.setInt(7, temp);
            pstmt.setInt(8, humiA);
            pstmt.setInt(9, humiT);
            pstmt.executeUpdate();
        } catch (SQLException e) {
            e.printStackTrace();
        }
    }
    
    public void selectMonthData(int month){
        String sql = "SELECT week, day, hour, min, intensity, temperature, humidityAir, humidityPlant FROM data WHERE month = ?";
        
        try (Connection conn = this.connect();
             PreparedStatement pstmt  = conn.prepareStatement(sql)){
            
            // set the value
            pstmt.setInt(1,month);
            //
            ResultSet rs  = pstmt.executeQuery();
            
            // loop through the result set
            while (rs.next()) {
                System.out.println(rs.getInt("week") + "\t" +
                                   rs.getInt("day") +  "\t" + 
                                   rs.getInt("hour") +  "\t" + 
                                   rs.getInt("min") +  "\t" + 
                                   rs.getInt("intensity") +  "\t" + 
                                   rs.getInt("temperature") +  "\t" + 
                                   rs.getInt("humidityAir") +  "\t" + 
                                   rs.getInt("humidityPlant") +  "\t"
                                   );
            }
        } catch (SQLException e) {
            e.printStackTrace();
        }
             
    }
    
    public void selectWeekOfMonthData(int month, int week){
        String sql = "SELECT day, hour, min, intensity, temperature, humidityAir, humidityPlant FROM data WHERE month = ? and week = ?";
        
        try (Connection conn = this.connect();
             PreparedStatement pstmt  = conn.prepareStatement(sql)){
            
            // set the value
            pstmt.setInt(1,month);
            pstmt.setInt(2,week);
            //
            ResultSet rs  = pstmt.executeQuery();
            
            // loop through the result set
            while (rs.next()) {
                System.out.println(rs.getInt("day") +  "\t" + 
                                   rs.getInt("hour") +  "\t" + 
                                   rs.getInt("min") +  "\t" + 
                                   rs.getInt("intensity") +  "\t" + 
                                   rs.getInt("temperature") +  "\t" + 
                                   rs.getInt("humidityAir") +  "\t" + 
                                   rs.getInt("humidityPlant") +  "\t"
                                   );
            }
        } catch (SQLException e) {
            e.printStackTrace();
        }
             
    }
    
    public void selectDayOfMonthData(int month, int day){
        String sql = "SELECT hour, min, intensity, temperature, humidityAir, humidityPlant FROM data WHERE month = ? and day = ?";
        
        try (Connection conn = this.connect();
             PreparedStatement pstmt  = conn.prepareStatement(sql)){
            
            // set the value
            pstmt.setInt(1,month);
            pstmt.setInt(2,day);
            //
            ResultSet rs  = pstmt.executeQuery();
            
            // loop through the result set
            while (rs.next()) {
                System.out.println(rs.getInt("hour") +  "\t" + 
                                   rs.getInt("min") +  "\t" + 
                                   rs.getInt("intensity") +  "\t" + 
                                   rs.getInt("temperature") +  "\t" + 
                                   rs.getInt("humidityAir") +  "\t" + 
                                   rs.getInt("humidityPlant") +  "\t"
                                   );
            }
        } catch (SQLException e) {
            e.printStackTrace();
        }
             
    }
    
    public List<String> selectDayOfMonths(){
        String sql = "SELECT DISTINCT month, day FROM data";
        ArrayList<String> res = new ArrayList<String>();
        
        try (Connection conn = this.connect();
             PreparedStatement pstmt  = conn.prepareStatement(sql)){
            
            ResultSet rs  = pstmt.executeQuery();
            
            // loop through the result set
            while (rs.next()) {
                res.add(months[rs.getInt("month")] + " : " + rs.getInt("day"));
                System.out.println(months[rs.getInt("month")] + " : J " + rs.getInt("day"));
            }
        } catch (SQLException e) {
            e.printStackTrace();
            return null;
        }  
        return res;
    }
    
    public List<String> selectWeekOfMonth(){
        String sql = "SELECT DISTINCT month, week FROM data";
        ArrayList<String> res = new ArrayList<String>();
        
        try (Connection conn = this.connect();
             PreparedStatement pstmt  = conn.prepareStatement(sql)){
            
            ResultSet rs  = pstmt.executeQuery();
            
            // loop through the result set
            while (rs.next()) {
                res.add(months[rs.getInt("month")] + " :  Sem. " + rs.getInt("week"));
                System.out.println(months[rs.getInt("month")] + " :  Sem. " + rs.getInt("week"));
            }
        } catch (SQLException e) {
            e.printStackTrace();
            return null;
        }  
        return res;
    }
    
    public List<String> selectMonth(){
        String sql = "SELECT DISTINCT month FROM data";
        ArrayList<String> res = new ArrayList<String>();
        
        try (Connection conn = this.connect();
             PreparedStatement pstmt  = conn.prepareStatement(sql)){
            
            ResultSet rs  = pstmt.executeQuery();
            
            // loop through the result set
            while (rs.next()) {
                res.add(months[rs.getInt("month")]);
                System.out.println(months[rs.getInt("month")]);
            }
        } catch (SQLException e) {
            e.printStackTrace();
            return null;
        }
        
        return res;
    }
    
}
